@@ -10,7 +10,7 @@ class EzspStruct:
                 setattr(self, field[0], getattr(args[0], field[0]))
 
     def serialize(self):
-        r = b''
+        r = b""
         for field in self._fields:
             r += getattr(self, field[0]).serialize()
         return r
@@ -24,11 +24,11 @@ class EzspStruct:
         return r, data
 
     def __repr__(self):
-        r = '<%s ' % (self.__class__.__name__, )
-        r += ' '.join(
-            ['%s=%s' % (f[0], getattr(self, f[0], None)) for f in self._fields]
+        r = "<%s " % (self.__class__.__name__,)
+        r += " ".join(
+            ["%s=%s" % (f[0], getattr(self, f[0], None)) for f in self._fields]
         )
-        r += '>'
+        r += ">"
         return r
 
 
@@ -36,29 +36,29 @@ class EmberNetworkParameters(EzspStruct):
     # Network parameters.
     _fields = [
         # The network's extended PAN identifier.
-        ('extendedPanId', basic.fixed_list(8, basic.uint8_t)),
+        ("extendedPanId", basic.fixed_list(8, basic.uint8_t)),
         # The network's PAN identifier.
-        ('panId', basic.uint16_t),
+        ("panId", basic.uint16_t),
         # A power setting, in dBm.
-        ('radioTxPower', basic.uint8_t),
+        ("radioTxPower", basic.uint8_t),
         # A radio channel.
-        ('radioChannel', basic.uint8_t),
+        ("radioChannel", basic.uint8_t),
         # The method used to initially join the network.
-        ('joinMethod', named.EmberJoinMethod),
+        ("joinMethod", named.EmberJoinMethod),
         # NWK Manager ID. The ID of the network manager in the current network.
         # This may only be set at joining when using USE_NWK_COMMISSIONING as
         # the join method.
-        ('nwkManagerId', named.EmberNodeId),
+        ("nwkManagerId", named.EmberNodeId),
         # NWK Update ID. The value of the ZigBee nwkUpdateId known by the
         # stack. This is used to determine the newest instance of the network
         # after a PAN ID or channel change. This may only be set at joining
         # when using USE_NWK_COMMISSIONING as the join method.
-        ('nwkUpdateId', basic.uint8_t),
+        ("nwkUpdateId", basic.uint8_t),
         # NWK channel mask. The list of preferred channels that the NWK manager
         # has told this device to use when searching for the network. This may
         # only be set at joining when using USE_NWK_COMMISSIONING as the join
         # method.
-        ('channels', basic.uint32_t),
+        ("channels", basic.uint32_t),
     ]
 
 
@@ -66,17 +66,17 @@ class EmberZigbeeNetwork(EzspStruct):
     # The parameters of a ZigBee network.
     _fields = [
         # The 802.15.4 channel associated with the network.
-        ('channel', basic.uint8_t),
+        ("channel", basic.uint8_t),
         # The network's PAN identifier.
-        ('panId', basic.uint16_t),
+        ("panId", basic.uint16_t),
         # The network's extended PAN identifier.
-        ('extendedPanId', basic.fixed_list(8, basic.uint8_t)),
+        ("extendedPanId", basic.fixed_list(8, basic.uint8_t)),
         # Whether the network is allowing MAC associations.
-        ('allowingJoin', named.Bool),
+        ("allowingJoin", named.Bool),
         # The Stack Profile associated with the network.
-        ('stackProfile', basic.uint8_t),
+        ("stackProfile", basic.uint8_t),
         # The instance of the Network.
-        ('nwkUpdateId', basic.uint8_t),
+        ("nwkUpdateId", basic.uint8_t),
     ]
 
 
@@ -84,19 +84,19 @@ class EmberApsFrame(EzspStruct):
     # ZigBee APS frame parameters.
     _fields = [
         # The application profile ID that describes the format of the message.
-        ('profileId', basic.uint16_t),
+        ("profileId", basic.uint16_t),
         # The cluster ID for this message.
-        ('clusterId', basic.uint16_t),
+        ("clusterId", basic.uint16_t),
         # The source endpoint.
-        ('sourceEndpoint', basic.uint8_t),
+        ("sourceEndpoint", basic.uint8_t),
         # The destination endpoint.
-        ('destinationEndpoint', basic.uint8_t),
+        ("destinationEndpoint", basic.uint8_t),
         # A bitmask of options.
-        ('options', named.EmberApsOption),
+        ("options", named.EmberApsOption),
         # The group ID for this message, if it is multicast mode.
-        ('groupId', basic.uint16_t),
+        ("groupId", basic.uint16_t),
         # The sequence number.
-        ('sequence', basic.uint8_t),
+        ("sequence", basic.uint8_t),
     ]
 
 
@@ -104,23 +104,23 @@ class EmberBindingTableEntry(EzspStruct):
     # An entry in the binding table.
     _fields = [
         # The type of binding.
-        ('type', named.EmberBindingType),
+        ("type", named.EmberBindingType),
         # The endpoint on the local node.
-        ('local', basic.uint8_t),
+        ("local", basic.uint8_t),
         # A cluster ID that matches one from the local endpoint's simple
         # descriptor. This cluster ID is set by the provisioning application to
         # indicate which part an endpoint's functionality is bound to this
         # particular remote node and is used to distinguish between unicast and
         # multicast bindings. Note that a binding can be used to send messages
         # with any cluster ID, not just that listed in the binding.
-        ('clusterId', basic.uint16_t),
+        ("clusterId", basic.uint16_t),
         # The endpoint on the remote node (specified by identifier).
-        ('remote', basic.uint8_t),
+        ("remote", basic.uint8_t),
         # A 64-bit identifier. This is either the destination EUI64 (for
         # unicasts) or the 64-bit group address (for multicasts).
-        ('identifier', named.EmberEUI64),
+        ("identifier", named.EmberEUI64),
         # The index of the network the binding belongs to.
-        ('networkIndex', basic.uint8_t),
+        ("networkIndex", basic.uint8_t),
     ]
 
 
@@ -130,12 +130,12 @@ class EmberMulticastTableEntry(EzspStruct):
     # multicast group will receive messages sent to that multicast group.
     _fields = [
         # The multicast group ID.
-        ('multicastId', named.EmberMulticastId),
+        ("multicastId", named.EmberMulticastId),
         # The endpoint that is a member, or 0 if this entry is not in use (the
         # ZDO is not a member of any multicast groups.)
-        ('endpoint', basic.uint8_t),
+        ("endpoint", basic.uint8_t),
         # The network index of the network the entry is related to.
-        ('networkIndex', basic.uint8_t),
+        ("networkIndex", basic.uint8_t),
     ]
 
 
@@ -143,7 +143,7 @@ class EmberKeyData(EzspStruct):
     # A 128-bit key.
     _fields = [
         # The key data.
-        ('contents', basic.fixed_list(16, basic.uint8_t)),
+        ("contents", basic.fixed_list(16, basic.uint8_t))
     ]
 
 
@@ -151,7 +151,7 @@ class EmberCertificateData(EzspStruct):
     # The implicit certificate used in CBKE.
     _fields = [
         # The certificate data.
-        ('contents', basic.fixed_list(48, basic.uint8_t)),
+        ("contents", basic.fixed_list(48, basic.uint8_t))
     ]
 
 
@@ -159,7 +159,7 @@ class EmberPublicKeyData(EzspStruct):
     # The public key data used in CBKE.
     _fields = [
         # The public key data.
-        ('contents', basic.fixed_list(22, basic.uint8_t)),
+        ("contents", basic.fixed_list(22, basic.uint8_t))
     ]
 
 
@@ -167,7 +167,7 @@ class EmberPrivateKeyData(EzspStruct):
     # The private key data used in CBKE.
     _fields = [
         # The private key data.
-        ('contents', basic.fixed_list(21, basic.uint8_t)),
+        ("contents", basic.fixed_list(21, basic.uint8_t))
     ]
 
 
@@ -175,14 +175,14 @@ class EmberTransientKeyData(EzspStruct):
     # The transient key data structure
     _fields = [
         # The IEEE address paired with the transient link key.
-        ('eui64', named.EmberEUI64),
+        ("eui64", named.EmberEUI64),
         # The key data structure matching the transient key.
-        ('keyData', EmberKeyData),
+        ("keyData", EmberKeyData),
         # The incoming frame counter associated with this key.
-        ('incomingFrameCounter', basic.uint32_t),
+        ("incomingFrameCounter", basic.uint32_t),
         # The number of milliseconds remaining before the key
         # is automatically timed out of the transient key table.
-        ('countdownTimerMs', basic.uint32_t),
+        ("countdownTimerMs", basic.uint32_t),
     ]
 
 
@@ -190,7 +190,7 @@ class EmberSmacData(EzspStruct):
     # The Shared Message Authentication Code data used in CBKE.
     _fields = [
         # The Shared Message Authentication Code data.
-        ('contents', basic.fixed_list(16, basic.uint8_t)),
+        ("contents", basic.fixed_list(16, basic.uint8_t))
     ]
 
 
@@ -198,7 +198,7 @@ class EmberSignatureData(EzspStruct):
     # An ECDSA signature
     _fields = [
         # The signature data.
-        ('contents', basic.fixed_list(42, basic.uint8_t)),
+        ("contents", basic.fixed_list(42, basic.uint8_t))
     ]
 
 
@@ -206,7 +206,7 @@ class EmberCertificate283k1Data(EzspStruct):
     # The implicit certificate used in CBKE.
     _fields = [
         # The 283k1 certificate data.
-        ('contents', basic.fixed_list(74, basic.uint8_t)),
+        ("contents", basic.fixed_list(74, basic.uint8_t))
     ]
 
 
@@ -214,7 +214,7 @@ class EmberPublicKey283k1Data(EzspStruct):
     # The public key data used in CBKE.
     _fields = [
         # The 283k1 public key data.
-        ('contents', basic.fixed_list(37, basic.uint8_t)),
+        ("contents", basic.fixed_list(37, basic.uint8_t))
     ]
 
 
@@ -222,7 +222,7 @@ class EmberPrivateKey283k1Data(EzspStruct):
     # The private key data used in CBKE.
     _fields = [
         # The 283k1 private key data.
-        ('contents', basic.fixed_list(36, basic.uint8_t)),
+        ("contents", basic.fixed_list(36, basic.uint8_t))
     ]
 
 
@@ -230,7 +230,7 @@ class EmberSignature283k1Data(EzspStruct):
     # An ECDSA signature
     _fields = [
         # The 283k1 signature data.
-        ('contents', basic.fixed_list(72, basic.uint8_t)),
+        ("contents", basic.fixed_list(72, basic.uint8_t))
     ]
 
 
@@ -238,7 +238,7 @@ class EmberMessageDigest(EzspStruct):
     # The calculated digest of a message
     _fields = [
         # The calculated digest of a message.
-        ('contents', basic.fixed_list(16, basic.uint8_t)),
+        ("contents", basic.fixed_list(16, basic.uint8_t))
     ]
 
 
@@ -246,9 +246,9 @@ class EmberAesMmoHashContext(EzspStruct):
     # The hash context for an ongoing hash operation.
     _fields = [
         # The result of ongoing the hash operation.
-        ('result', basic.fixed_list(16, basic.uint8_t)),
+        ("result", basic.fixed_list(16, basic.uint8_t)),
         # The total length of the data that has been hashed so far.
-        ('length', basic.uint32_t),
+        ("length", basic.uint32_t),
     ]
 
 
@@ -257,24 +257,24 @@ class EmberNeighborTableEntry(EzspStruct):
     # links to and from neighboring nodes.
     _fields = [
         # The neighbor's two byte network id
-        ('shortId', basic.uint16_t),
+        ("shortId", basic.uint16_t),
         # An exponentially weighted moving average of the link quality values
         # of incoming packets from this neighbor as reported by the PHY.
-        ('averageLqi', basic.uint8_t),
+        ("averageLqi", basic.uint8_t),
         # The incoming cost for this neighbor, computed from the average LQI.
         # Values range from 1 for a good link to 7 for a bad link.
-        ('inCost', basic.uint8_t),
+        ("inCost", basic.uint8_t),
         # The outgoing cost for this neighbor, obtained from the most recently
         # received neighbor exchange message from the neighbor. A value of zero
         # means that a neighbor exchange message from the neighbor has not been
         # received recently enough, or that our id was not present in the most
         # recently received one.
-        ('outCost', basic.uint8_t),
+        ("outCost", basic.uint8_t),
         # The number of aging periods elapsed since a link status message was
         # last received from this neighbor. The aging period is 16 seconds.
-        ('age', basic.uint8_t),
+        ("age", basic.uint8_t),
         # The 8 byte EUI64 of the neighbor.
-        ('longId', named.EmberEUI64),
+        ("longId", named.EmberEUI64),
     ]
 
 
@@ -284,22 +284,22 @@ class EmberRouteTableEntry(EzspStruct):
     _fields = [
         # The short id of the destination. A value of 0xFFFF indicates the
         # entry is unused.
-        ('destination', basic.uint16_t),
+        ("destination", basic.uint16_t),
         # The short id of the next hop to this destination.
-        ('nextHop', basic.uint16_t),
+        ("nextHop", basic.uint16_t),
         # Indicates whether this entry is active (0), being discovered (1)),
         # unused (3), or validating (4).
-        ('status', basic.uint8_t),
+        ("status", basic.uint8_t),
         # The number of seconds since this route entry was last used to send a
         # packet.
-        ('age', basic.uint8_t),
+        ("age", basic.uint8_t),
         # Indicates whether this destination is a High RAM Concentrator (2), a
         # Low RAM Concentrator (1), or not a concentrator (0).
-        ('concentratorType', basic.uint8_t),
+        ("concentratorType", basic.uint8_t),
         # For a High RAM Concentrator, indicates whether a route record is
         # needed (2), has been sent (1), or is no long needed (0) because a
         # source routed message from the concentrator has been received.
-        ('routeRecordState', basic.uint8_t),
+        ("routeRecordState", basic.uint8_t),
     ]
 
 
@@ -310,20 +310,20 @@ class EmberInitialSecurityState(EzspStruct):
         # A bitmask indicating the security state used to indicate what the
         # security configuration will be when the device forms or joins the
         # network.
-        ('bitmask', named.EmberInitialSecurityBitmask),
+        ("bitmask", named.EmberInitialSecurityBitmask),
         # The pre-configured Key data that should be used when forming or
         # joining the network. The security bitmask must be set with the
         # HAVE_PRECONFIGURED_KEY bit to indicate that the key contains valid
         # data.
-        ('preconfiguredKey', EmberKeyData),
+        ("preconfiguredKey", EmberKeyData),
         # The Network Key that should be used by the Trust Center when it forms
         # the network, or the Network Key currently in use by a joined device.
         # The security bitmask must be set with HAVE_NETWORK_KEY to indicate
         # that the key contains valid data.
-        ('networkKey', EmberKeyData),
+        ("networkKey", EmberKeyData),
         # The sequence number associated with the network key. This is only
         # valid if the HAVE_NETWORK_KEY has been set in the security bitmask.
-        ('networkKeySequenceNumber', basic.uint8_t),
+        ("networkKeySequenceNumber", basic.uint8_t),
         # This is the long address of the trust center on the network that will
         # be joined. It is usually NOT set prior to joining the network and
         # instead it is learned during the joining message exchange. This field
@@ -331,7 +331,7 @@ class EmberInitialSecurityState(EzspStruct):
         # EmberInitialSecurityState::bitmask. Most devices should clear that
         # bit and leave this field alone. This field must be set when using
         # commissioning mode.
-        ('preconfiguredTrustCenterEui64', named.EmberEUI64),
+        ("preconfiguredTrustCenterEui64", named.EmberEUI64),
     ]
 
 
@@ -340,9 +340,9 @@ class EmberCurrentSecurityState(EzspStruct):
     _fields = [
         # A bitmask indicating the security options currently in use by a
         # device joined in the network.
-        ('bitmask', named.EmberCurrentSecurityBitmask),
+        ("bitmask", named.EmberCurrentSecurityBitmask),
         # The IEEE Address of the Trust Center device.
-        ('trustCenterLongAddress', named.EmberEUI64),
+        ("trustCenterLongAddress", named.EmberEUI64),
     ]
 
 
@@ -351,19 +351,19 @@ class EmberKeyStruct(EzspStruct):
     _fields = [
         # A bitmask indicating the presence of data within the various fields
         # in the structure.
-        ('bitmask', named.EmberKeyStructBitmask),
+        ("bitmask", named.EmberKeyStructBitmask),
         # The type of the key.
-        ('type', named.EmberKeyType),
+        ("type", named.EmberKeyType),
         # The actual key data.
-        ('key', EmberKeyData),
+        ("key", EmberKeyData),
         # The outgoing frame counter associated with the key.
-        ('outgoingFrameCounter', basic.uint32_t),
+        ("outgoingFrameCounter", basic.uint32_t),
         # The frame counter of the partner device associated with the key.
-        ('incomingFrameCounter', basic.uint32_t),
+        ("incomingFrameCounter", basic.uint32_t),
         # The sequence number associated with the key.
-        ('sequenceNumber', basic.uint8_t),
+        ("sequenceNumber", basic.uint8_t),
         # The IEEE address of the partner device also in possession of the key.
-        ('partnerEUI64', named.EmberEUI64),
+        ("partnerEUI64", named.EmberEUI64),
     ]
 
 
@@ -371,7 +371,7 @@ class EmberNetworkInitStruct(EzspStruct):
     # Network Initialization parameters.
     _fields = [
         # Configuration options for network init.
-        ('bitmask', named.EmberNetworkInitBitmask),
+        ("bitmask", named.EmberNetworkInitBitmask)
     ]
 
 
@@ -379,11 +379,11 @@ class EmberZllSecurityAlgorithmData(EzspStruct):
     # Data associated with the ZLL security algorithm.
     _fields = [
         # Transaction identifier.
-        ('transactionId', basic.uint32_t),
+        ("transactionId", basic.uint32_t),
         # Response identifier.
-        ('responseId', basic.uint32_t),
+        ("responseId", basic.uint32_t),
         # Bitmask.
-        ('bitmask', basic.uint16_t),
+        ("bitmask", basic.uint16_t),
     ]
 
 
@@ -391,23 +391,23 @@ class EmberZllNetwork(EzspStruct):
     # The parameters of a ZLL network.
     _fields = [
         # The parameters of a ZigBee network.
-        ('zigbeeNetwork', EmberZigbeeNetwork),
+        ("zigbeeNetwork", EmberZigbeeNetwork),
         # Data associated with the ZLL security algorithm.
-        ('securityAlgorithm', EmberZllSecurityAlgorithmData),
+        ("securityAlgorithm", EmberZllSecurityAlgorithmData),
         # Associated EUI64.
-        ('eui64', named.EmberEUI64),
+        ("eui64", named.EmberEUI64),
         # The node id.
-        ('nodeId', named.EmberNodeId),
+        ("nodeId", named.EmberNodeId),
         # The ZLL state.
-        ('state', named.EmberZllState),
+        ("state", named.EmberZllState),
         # The node type.
-        ('nodeType', named.EmberNodeType),
+        ("nodeType", named.EmberNodeType),
         # The number of sub devices.
-        ('numberSubDevices', basic.uint8_t),
+        ("numberSubDevices", basic.uint8_t),
         # The total number of group identifiers.
-        ('totalGroupIdentifiers', basic.uint8_t),
+        ("totalGroupIdentifiers", basic.uint8_t),
         # RSSI correction value.
-        ('rssiCorrection', basic.uint8_t),
+        ("rssiCorrection", basic.uint8_t),
     ]
 
 
@@ -416,14 +416,14 @@ class EmberZllInitialSecurityState(EzspStruct):
     # used when forming or joining ZLL networks.
     _fields = [
         # Unused bitmask; reserved for future use.
-        ('bitmask', basic.uint32_t),
+        ("bitmask", basic.uint32_t),
         # The key encryption algorithm advertised by the application.
-        ('keyIndex', named.EmberZllKeyIndex),
+        ("keyIndex", named.EmberZllKeyIndex),
         # The encryption key for use by algorithms that require it.
-        ('encryptionKey', EmberKeyData),
+        ("encryptionKey", EmberKeyData),
         # The pre-configured link key used during classical ZigBee
         # commissioning.
-        ('preconfiguredKey', EmberKeyData),
+        ("preconfiguredKey", EmberKeyData),
     ]
 
 
@@ -431,17 +431,17 @@ class EmberZllDeviceInfoRecord(EzspStruct):
     # Information about a specific ZLL Device.
     _fields = [
         # EUI64 associated with the device.
-        ('ieeeAddress', named.EmberEUI64),
+        ("ieeeAddress", named.EmberEUI64),
         # Endpoint id.
-        ('endpointId', basic.uint8_t),
+        ("endpointId", basic.uint8_t),
         # Profile id.
-        ('profileId', basic.uint16_t),
+        ("profileId", basic.uint16_t),
         # Device id.
-        ('deviceId', basic.uint16_t),
+        ("deviceId", basic.uint16_t),
         # Associated version.
-        ('version', basic.uint8_t),
+        ("version", basic.uint8_t),
         # Number of relevant group ids.
-        ('groupIdCount', basic.uint8_t),
+        ("groupIdCount", basic.uint8_t),
     ]
 
 
@@ -449,19 +449,19 @@ class EmberZllAddressAssignment(EzspStruct):
     # ZLL address assignment data.
     _fields = [
         # Relevant node id.
-        ('nodeId', named.EmberNodeId),
+        ("nodeId", named.EmberNodeId),
         # Minimum free node id.
-        ('freeNodeIdMin', named.EmberNodeId),
+        ("freeNodeIdMin", named.EmberNodeId),
         # Maximum free node id.
-        ('freeNodeIdMax', named.EmberNodeId),
+        ("freeNodeIdMax", named.EmberNodeId),
         # Minimum group id.
-        ('groupIdMin', named.EmberMulticastId),
+        ("groupIdMin", named.EmberMulticastId),
         # Maximum group id.
-        ('groupIdMax', named.EmberMulticastId),
+        ("groupIdMax", named.EmberMulticastId),
         # Minimum free group id.
-        ('freeGroupIdMin', named.EmberMulticastId),
+        ("freeGroupIdMin", named.EmberMulticastId),
         # Maximum free group id.
-        ('freeGroupIdMax', named.EmberMulticastId),
+        ("freeGroupIdMax", named.EmberMulticastId),
     ]
 
 
@@ -469,19 +469,19 @@ class EmberTokTypeStackZllData(EzspStruct):
     # Public API for ZLL stack data token.
     _fields = [
         # Token bitmask.
-        ('bitmask', basic.uint32_t),
+        ("bitmask", basic.uint32_t),
         # Minimum free node id.
-        ('freeNodeIdMin', basic.uint16_t),
+        ("freeNodeIdMin", basic.uint16_t),
         # Maximum free node id.
-        ('freeNodeIdMax', basic.uint16_t),
+        ("freeNodeIdMax", basic.uint16_t),
         # Local minimum group id.
-        ('myGroupIdMin', basic.uint16_t),
+        ("myGroupIdMin", basic.uint16_t),
         # Minimum free group id.
-        ('freeGroupIdMin', basic.uint16_t),
+        ("freeGroupIdMin", basic.uint16_t),
         # Maximum free group id.
-        ('freeGroupIdMax', basic.uint16_t),
+        ("freeGroupIdMax", basic.uint16_t),
         # RSSI correction value.
-        ('rssiCorrection', basic.uint8_t),
+        ("rssiCorrection", basic.uint8_t),
     ]
 
 
@@ -489,13 +489,13 @@ class EmberTokTypeStackZllSecurity(EzspStruct):
     # Public API for ZLL stack security token.
     _fields = [
         # Token bitmask.
-        ('bitmask', basic.uint32_t),
+        ("bitmask", basic.uint32_t),
         # Key index.
-        ('keyIndex', basic.uint8_t),
+        ("keyIndex", basic.uint8_t),
         # Encryption key.
-        ('encryptionKey', basic.fixed_list(16, basic.uint8_t)),
+        ("encryptionKey", basic.fixed_list(16, basic.uint8_t)),
         # Preconfigured key.
-        ('preconfiguredKey', basic.fixed_list(16, basic.uint8_t)),
+        ("preconfiguredKey", basic.fixed_list(16, basic.uint8_t)),
     ]
 
 
@@ -504,9 +504,9 @@ class EmberRf4ceVendorInfo(EzspStruct):
     _fields = [
         # The vendor identifier field shall contain the vendor identifier of
         # the node.
-        ('vendorId', basic.uint16_t),
+        ("vendorId", basic.uint16_t),
         # The vendor string field shall contain the vendor string of the node.
-        ('vendorString', basic.fixed_list(7, basic.uint8_t)),
+        ("vendorString", basic.fixed_list(7, basic.uint8_t)),
     ]
 
 
@@ -515,16 +515,16 @@ class EmberRf4ceApplicationInfo(EzspStruct):
     _fields = [
         # The application capabilities field shall contain information relating
         # to the capabilities of the application of the node.
-        ('capabilities', named.EmberRf4ceApplicationCapabilities),
+        ("capabilities", named.EmberRf4ceApplicationCapabilities),
         # The user string field shall contain the user specified identification
         # string.
-        ('userString', basic.fixed_list(15, basic.uint8_t)),
+        ("userString", basic.fixed_list(15, basic.uint8_t)),
         # The device type list field shall contain the list of device types
         # supported by the node.
-        ('deviceTypeList', basic.fixed_list(3, basic.uint8_t)),
+        ("deviceTypeList", basic.fixed_list(3, basic.uint8_t)),
         # The profile ID list field shall contain the list of profile
         # identifiers disclosed as supported by the node.
-        ('profileIdList', basic.fixed_list(7, basic.uint8_t)),
+        ("profileIdList", basic.fixed_list(7, basic.uint8_t)),
     ]
 
 
@@ -532,31 +532,31 @@ class EmberRf4cePairingTableEntry(EzspStruct):
     # The internal representation of an RF4CE pairing table entry.
     _fields = [
         # The link key to be used to secure this pairing link.
-        ('securityLinkKey', EmberKeyData),
+        ("securityLinkKey", EmberKeyData),
         # The IEEE address of the destination device.
-        ('destLongId', named.EmberEUI64),
+        ("destLongId", named.EmberEUI64),
         # The frame counter last received from the recipient node.
-        ('frameCounter', basic.uint32_t),
+        ("frameCounter", basic.uint32_t),
         # The network address to be assumed by the source device.
-        ('sourceNodeId', named.EmberNodeId),
+        ("sourceNodeId", named.EmberNodeId),
         # The PAN identifier of the destination device.
-        ('destPanId', named.EmberPanId),
+        ("destPanId", named.EmberPanId),
         # The network address of the destination device.
-        ('destNodeId', named.EmberNodeId),
+        ("destNodeId", named.EmberNodeId),
         # The vendor ID of the destination device.
-        ('destVendorId', basic.uint16_t),
+        ("destVendorId", basic.uint16_t),
         # The list of profiles supported by the destination device.
-        ('destProfileIdList', basic.fixed_list(7, basic.uint8_t)),
+        ("destProfileIdList", basic.fixed_list(7, basic.uint8_t)),
         # The length of the list of supported profiles.
-        ('destProfileIdListLength', basic.uint8_t),
+        ("destProfileIdListLength", basic.uint8_t),
         # Info byte.
-        ('info', basic.uint8_t),
+        ("info", basic.uint8_t),
         # The expected channel of the destination device.
-        ('channel', basic.uint8_t),
+        ("channel", basic.uint8_t),
         # The node capabilities of the recipient node.
-        ('capabilities', basic.uint8_t),
+        ("capabilities", basic.uint8_t),
         # Last MAC sequence number seen on this pairing link.
-        ('lastSeqn', basic.uint8_t),
+        ("lastSeqn", basic.uint8_t),
     ]
 
 
@@ -564,13 +564,13 @@ class EmberGpAddress(EzspStruct):
     # A GP address structure.
     _fields = [
         # The GPD's EUI64.
-        ('gpdIeeeAddress', named.EmberEUI64),
+        ("gpdIeeeAddress", named.EmberEUI64),
         # The GPD's source ID.
-        ('sourceId', basic.uint32_t),
+        ("sourceId", basic.uint32_t),
         # The GPD Application ID.
-        ('applicationId', basic.uint8_t),
+        ("applicationId", basic.uint8_t),
         # The GPD endpoint.
-        ('endpoint', basic.uint8_t),
+        ("endpoint", basic.uint8_t),
     ]
 
 
@@ -578,9 +578,9 @@ class EmberGpSinkListEntry(EzspStruct):
     # A sink list entry
     _fields = [
         # The sink list type.
-        ('type', basic.uint8_t),
+        ("type", basic.uint8_t),
         # The EUI64 of the target sink.
-        ('sinkEUI', named.EmberEUI64),
+        ("sinkEUI", named.EmberEUI64),
         # The short address of the target sink.
-        ('sinkNodeId', named.EmberNodeId),
+        ("sinkNodeId", named.EmberNodeId),
     ]
